@@ -31,7 +31,7 @@ void ffi_defs(void)
   pure_def(pure_sym("FFI_SYSV"), pure_int(FFI_SYSV));
   pure_def(pure_sym("FFI_STDCALL"), pure_int(FFI_STDCALL));
 #else
-#if defined(__i386__) || defined(__x86_64__)
+#if (defined(__i386__) || defined(__x86_64__)) && !defined(__MINGW64__)
   pure_def(pure_sym("FFI_SYSV"), pure_int(FFI_SYSV));
   pure_def(pure_sym("FFI_UNIX64"), pure_int(FFI_UNIX64));
 #endif
